@@ -17,13 +17,9 @@ class LibFiles():
     def templates_dir(self):
         return self.install.joinpath('templates')
 
-    @property
-    def assets_dir(self):
-        return self.install.joinpath('assets')
-
     @property
     def static_dir(self):
-        return self.assets_dir.joinpath('static')
+        return self.install.joinpath('http', 'static')
 
     @property
     def pytop5js(self):
@@ -31,11 +27,11 @@ class LibFiles():
 
     @property
     def p5js(self):
-        return self.static_dir.joinpath('p5', 'p5.min.js')
+        return self.static_dir.joinpath('js', 'p5', 'p5.min.js')
 
     @property
     def p5_yml(self):
-        return self.assets_dir.joinpath('p5_reference.yml')
+        return self.static_dir.joinpath('p5_reference.yml')
 
     ##### TRANSCRYPT SPECIFICS
 
@@ -69,5 +65,9 @@ class LibFiles():
     def pyodide_base_sketch_template(self):
         return self.templates_dir.joinpath('pyodide', 'base_sketch.py.template')
 
+    @property
+    def pyodide_js_dir(self):
+        return self.static_dir / "js" / "pyodide"
+
 
 PYP5JS_FILES = LibFiles()
