@@ -1,13 +1,14 @@
 import os
 import re
+import shutil
 from collections import namedtuple
 
 from pyp5js import config
+from pyp5js.config.fs import PYP5JS_FILES
 from pyp5js.config.sketch import SketchConfig
 from pyp5js.exceptions import SketchDirAlreadyExistException, InvalidName
 
-
-SketchUrls = namedtuple('SketchUrls', ['p5_js_url', 'sketch_js_url'])
+SketchUrls = namedtuple('SketchUrls', ['p5_js_url', 'pyodide_js_url', 'sketch_js_url'])
 
 
 class Sketch:
@@ -29,10 +30,13 @@ class Sketch:
         does_not_start_with_letter_or_underscore = r'^[^a-zA-Z_]'
         contains_non_alphanumerics_except_underscore = r'[^a-zA-Z0-9_]'
         if re.match(does_not_start_with_letter_or_underscore, self.sketch_name) or \
-           re.search(contains_non_alphanumerics_except_underscore, self.sketch_name):
+                re.search(contains_non_alphanumerics_except_underscore, self.sketch_name):
             raise InvalidName(self)
 
     def create_sketch_dir(self):
+        """
+        Create sketch required directories
+        """
         self.validate_name()
 
         if self.sketch_dir.exists():
@@ -43,6 +47,28 @@ class Sketch:
         self.target_dir.mkdir()
         self.config.write(self.config_file)
 
+    def copy_initial_files(self, use_cdn=True):
+        """
+        Copy requlred template files to the sketch directory
+        """
+        if not use_cdn:
+            self.config.p5_js_url = "/static/p5.js"
+            if self.config.is_pyodide:
+                self.config.pyodide_js_url = "/static/pyodide/pyodide_v0.18.1.js"
+
+        templates_files = [
+            (self.config.get_base_sketch_template(), self.sketch_py),
+        ]
+        if not use_cdn:
+            templates_files.append((PYP5JS_FILES.p5js, self.p5js))
+            if self.config.is_pyodide:
+                shutil.copytree(PYP5JS_FILES.pyodide_js_dir, self.static_dir / "pyodide")
+                # delete packages.json that's not necessary
+                (self.static_dir / "pyodide" / "packages.json").unlink()
+
+        for src, dest in templates_files:
+            shutil.copyfile(src, dest)
+
     @property
     def sketch_exists(self):
         return self.sketch_py.exists()
@@ -51,10 +77,9 @@ class Sketch:
     def sketch_content(self):
         if not self.sketch_py.exists():
             return ""
-        with self.sketch_py.open() as fd:
+        with self.sketch_py.open(encoding="utf-8") as fd:
             return fd.read()
 
-
     @property
     def has_all_files(self):
         return all([
@@ -109,6 +134,22 @@ class Sketch:
     @property
     def urls(self):
         return SketchUrls(
-            p5_js_url=f"{self.STATIC_NAME}/p5.js",
+            p5_js_url=self.config.p5_js_url,
+            pyodide_js_url=self.config.pyodide_js_url,
             sketch_js_url=f"{self.TARGET_NAME}/target_sketch.js",
         )
+
+    def get_target_sketch_context(self):
+        """
+        This method is used by the template renderers to get the context to be used
+        to render final target/target_sketch.js file.
+        """
+        context = {
+            "sketch_name": self.sketch_name,
+            "sketch_content": self.sketch_content,
+        }
+        if self.config.is_pyodide:
+            index = "/".join(self.config.pyodide_js_url.split("/")[:-1]) + "/"
+            context.update({'pyodide_index_url': index})
+        return context
+
