@@ -20,6 +20,7 @@ def get_sketch_index_content(sketch):
     context = {
         "sketch_name": sketch.sketch_name,
         "p5_js_url": sketch.urls.p5_js_url,
+        "pyodide_js_url": sketch.urls.pyodide_js_url,
         "sketch_js_url":  sketch.urls.sketch_js_url,
         "sketch_content": sketch.sketch_content,
     }
@@ -31,9 +32,6 @@ def get_target_sketch_content(sketch):
     """
     Renders the content to be written in the temporary SKETCH_NAME/target_sketch.py file
     """
-    context = {
-        "sketch_name": sketch.sketch_name,
-        "sketch_content": sketch.sketch_content,
-    }
+    context = sketch.get_target_sketch_context()
     target_js_file = sketch.config.get_target_js_template()
     return _template_from_file(target_js_file, context)
