@@ -12,9 +12,7 @@ def test_dir_properties(lib_files):
 
     assert lib_files.templates_dir == pyp5_dir.joinpath('templates')
     assert lib_files.templates_dir.exists()
-    assert lib_files.assets_dir == pyp5_dir.joinpath('assets')
-    assert lib_files.assets_dir.exists()
-    assert lib_files.static_dir == pyp5_dir.joinpath('assets', 'static')
+    assert lib_files.static_dir == pyp5_dir.joinpath('http', 'static')
     assert lib_files.static_dir.exists()
 
 
@@ -25,10 +23,10 @@ def test_files_properties(lib_files):
     assert lib_files.pytop5js == pyp5_dir.joinpath('templates', 'transcrypt', 'pyp5js.py')
     assert lib_files.pytop5js.exists()
 
-    assert lib_files.p5js == pyp5_dir.joinpath('assets', 'static', 'p5', 'p5.min.js')
+    assert lib_files.p5js == pyp5_dir.joinpath('http', 'static', 'js', 'p5', 'p5.min.js')
     assert lib_files.p5js.exists()
 
-    assert lib_files.p5_yml == pyp5_dir.joinpath('assets', 'p5_reference.yml')
+    assert lib_files.p5_yml == pyp5_dir.joinpath('http', 'static', 'p5_reference.yml')
     assert lib_files.p5_yml.exists()
 
 
